@@ -4,20 +4,23 @@ from scoss import smoss
 def test_smoss():
     sm = smoss.SMoss(lang='cpp')
     # print(sm.get_userid())
-    sm.add_file('./tests/data/a.cpp', "Thai")
+    # sm.add_file('./tests/data/a.cpp', "Thai")
     # sm.add_file('./tests/data/a.cpp', "Thai2")
-    sm.add_file('./tests/data/b.cpp', "Ngoc")
+    # sm.add_file('./tests/data/b.cpp', "Ngoc")
     # sm.add_file('./tests/data/b.cpp', "Ngoc2")
-    sm.add_file('./tests/data/c.cpp', "Vien")
+    # sm.add_file('./tests/data/c.cpp', "Vien")
     # sm.add_file('./tests/data/c.cpp', "Vien2")
-    sm.set_threshold(0.5)
-    sm.run()
+    # sm.add_file_by_wildcard("./tests/TTUD20201/GROUPUP/*.cpp")
+    sm.add_file_by_wildcard("tests/data/*")
+    # sm.set_threshold(0.5)
     # sm.run()
-    print(sm.get_lang())
+    sm.run()
+    # print(sm.get_lang())
     print(sm.get_matches())
-    print(sm.get_similarity_matrix())
-    sm.save_as_html('./tests/smoss_result/')
-    sm.save_matches_to_csv('./tests/smoss_result/')
+    print(sm.get_matches_file())
+    # print(sm.get_similarity_matrix())
+    # sm.save_as_html('./tests/smoss_result/')
+    # sm.save_matches_to_csv('./tests/smoss_result/')
     # print(sm.get_matches_file()['Ngoc']['Vien'])
     
 
